<?php

namespace Drupal\eco_mode\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\Renderer;
use Drupal\eco_mode\Manager\EcoModeManager;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Class EcoModeAjaxController. Controller for eco mode.
 *
 * @package Drupal\eco_mode\Controller
 */
class EcoModeAjaxController extends ControllerBase {

  /**
   * Eco mode manager.
   *
   * @var \Drupal\eco_mode\Manager\EcoModeManager
   *   The eco mode manager.
   */
  protected EcoModeManager $ecoModeManager;

  /**
   * Renderer.
   *
   * @var \Drupal\Core\Render\Renderer
   *   The renderer.
   */
  protected Renderer $renderer;

  /**
   * EcoModeAjaxController constructor.
   *
   * @param \Drupal\eco_mode\Manager\EcoModeManager $ecoModeManager
   *   The eco-mode manager.
   * @param \Drupal\Core\Render\Renderer $renderer
   *   The renderer.
   */
  public function __construct(EcoModeManager $ecoModeManager, Renderer $renderer) {
    $this->ecoModeManager = $ecoModeManager;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('eco_mode.eco_mode_manager'),
      $container->get('renderer')
    );
  }

  /**
   * Load field.
   *
   * @param string $entity_type
   *   Entity type.
   * @param string|int $entity_id
   *   Entity id.
   * @param string $field_name
   *   Field name.
   * @param string $token
   *   Token.
   * @param string $view_mode
   *   View mode.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The json response.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function loadField(string $entity_type, string | int $entity_id, string $field_name, string $token, string $view_mode): JsonResponse {
    $build = $this->ecoModeManager->renderField($entity_type, $entity_id, $field_name, $view_mode);
    $response = new AjaxResponse();
    $selector = '#eco-mode-ajax-field-link-' . $token;
    $response->addCommand(new ReplaceCommand($selector, $this->renderer->render($build)));

    return $response;
  }

}
