<?php

namespace Drupal\eco_mode\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\eco_mode\Manager\EcoModeManager;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class EcoModeController.
 *
 *   Eco mode controller.
 *
 * @package Drupal\eco_mode\Controller
 */
class EcoModeController extends ControllerBase {

  /**
   * Eco mode manager.
   *
   * @var \Drupal\eco_mode\Manager\EcoModeManager
   *   The eco mode manager.
   */
  protected EcoModeManager $ecoModeManager;

  /**
   * EcoModeController constructor.
   *
   * @param \Drupal\eco_mode\Manager\EcoModeManager $ecoModeManager
   *   The eco-mode manager.
   */
  public function __construct(EcoModeManager $ecoModeManager) {
    $this->ecoModeManager = $ecoModeManager;
  }

  /**
   * Redirect to the origin page with eco-mode switched on or off.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The redirect response.
   */
  public function switchEcoMode(Request $request): RedirectResponse {
    return $this->getResponse($request);
  }

  /**
   * Get the response.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The redirect response.
   */
  protected function getResponse(Request $request): RedirectResponse {
    $destination = $request->query->get('destination') ? $request->query->get('destination') : NULL;
    $redirectUrl = $destination ?? $this->ecoModeManager->getRequestReferUrl();
    $response = new RedirectResponse(urldecode($redirectUrl ?? '/'));

    $eco_mode_status = $this->ecoModeManager->getSwitchEcoModeNewCookieValue();
    $cookie = $this->ecoModeManager->getNewCookieObject($eco_mode_status);
    $this->ecoModeManager->setCookieValue($eco_mode_status);

    $response->headers->setCookie($cookie);

    return $response;
  }

}
