<?php

namespace Drupal\eco_mode;

use Drupal\Component\Utility\Html;
use Drupal\Component\Utility\Xss;
use Drupal\Core\Url;
use Drupal\eco_mode\Form\SettingsForm;
use Drupal\eco_mode\Manager\EcoModeManager;

/**
 * Class EcoModeHelper.
 *
 *   Helper class.
 *
 * @package eco_mode
 */
class EcoModeHelper {

  /**
   * Preprocess html.
   *
   * @param array $variables
   *   The variables.
   *
   * @return void
   *   Return void.
   */
  public static function preprocessHtml(array &$variables): void {
    /** @var \Drupal\eco_mode\Manager\EcoModeManager $ecoModeManager */
    $ecoModeManager = EcoModeManager::me();

    // Get the eco mode cookie value.
    $ecoModeCookieValue = $ecoModeManager->getEcoModeCookieValue();
    if ($ecoModeCookieValue) {
      $class = Html::cleanCssIdentifier('eco_mode');
      $variables['attributes']['class'][] = $class;
    }

    // Attach the library and settings.
    $variables['#attached']['drupalSettings']['eco_mode']['status'] = $ecoModeCookieValue;
    $variables['#attached']['library'][] = 'eco_mode/eco-mode';

    // Get the eco mode configuration.
    $ecoModeConfig = \Drupal::config('eco_mode.settings');

    // Get the eco mode admin page setting.
    $ecoModeAdminPage = $ecoModeConfig->get('enabled_admin_page');
    $variables['#attached']['drupalSettings']['eco_mode']['enabled_for_admin'] = (bool) $ecoModeAdminPage;
    $variables['#attached']['drupalSettings']['eco_mode']['is_admin_route'] = \Drupal::service('router.admin_context')->isAdminRoute();

    // Get the latency time.
    $latencyTime = $ecoModeConfig->get('latency');

    // If latency time is set, attach the settings to use in JS.
    if ($latencyTime) {
      $variables['#attached']['drupalSettings']['eco_mode']['latency'] = $latencyTime;
      $variables['#attached']['drupalSettings']['eco_mode']['interval'] = $ecoModeConfig->get('interval');
      $variables['#attached']['drupalSettings']['eco_mode']['switch_url'] = Url::fromRoute('eco_mode.eco_mode')->toString();
      $variables['#attached']['drupalSettings']['eco_mode']['message'] = Xss::filterAdmin($ecoModeConfig->get('prompt_message'));
      $variables['#attached']['drupalSettings']['eco_mode']['text_color'] = Xss::filter($ecoModeConfig->get('text_color'));
      $variables['#attached']['drupalSettings']['eco_mode']['background_color'] = Xss::filter($ecoModeConfig->get('background_color'));
    }
    // Handle cache tags.
    $variables['#cache']['tags'][] = 'config:' . SettingsForm::CONFIG_NAME;
  }

}
