<?php

namespace Drupal\eco_mode\EventSubscriber;

use Drupal\eco_mode\Manager\EcoModeManager;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Class EcoModeSubscriber.
 *
 *   Eco mode subscriber.
 *
 * @package Drupal\eco_mode\EventSubscriber
 */
class EcoModeSubscriber implements EventSubscriberInterface {

  /**
   * Eco mode manager.
   *
   * @var \Drupal\eco_mode\Manager\EcoModeManager
   *   The eco mode manager.
   */
  protected EcoModeManager $ecoModeManager;

  /**
   * EcoModeSubscriber constructor.
   *
   * @param \Drupal\eco_mode\Manager\EcoModeManager $ecoModeManager
   *   The eco-mode manager.
   */
  public function __construct(EcoModeManager $ecoModeManager) {
    $this->ecoModeManager = $ecoModeManager;
  }

  /**
   * Kernel response event handler.
   *
   * @param \Symfony\Component\HttpKernel\Event\ResponseEvent $event
   *   Response event.
   */
  public function onKernelResponse(ResponseEvent $event) {
    $value = $this->ecoModeManager->cookieExists() ? $this->ecoModeManager->getCookieValue() : 0;
    $ecoCookie = $this->ecoModeManager->getNewCookieObject($value);
    $response = $event->getResponse();
    $response->headers->setCookie($ecoCookie);
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      KernelEvents::RESPONSE => ['onKernelResponse'],
    ];
  }

}
