<?php

namespace Drupal\eco_mode\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Eco mode settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  const CONFIG_NAME = 'eco_mode.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'eco_mode_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['eco_mode.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['details'] = [
      '#type' => 'details',
      '#title' => $this->t('Banner'),
      '#open' => TRUE,
    ];

    $form['details']['latency'] = [
      '#type' => 'number',
      '#title' => $this->t('Maximum server response time (in milliseconds)'),
      '#min' => 0,
      '#default_value' => $this->config($this->getEditableConfigNames()[0])
        ->get('latency') ?? 0,
      '#description' => $this->t('The maximum time the server can take to respond to a request. If time is exceeded, a top banner will be displayed with the prompt message.'),
    ];

    $form['details']['interval'] = [
      '#type' => 'number',
      '#title' => $this->t('Request check interval (in seconds)'),
      '#min' => 0,
      '#default_value' => $this->config($this->getEditableConfigNames()[0])
        ->get('interval') ?? 0,
      '#description' => $this->t('The interval at which the request will be sent. If value is 0, server will be checked on every page load. It is recommended to set a great value in order to minimize server load.'),
    ];

    $form['details']['prompt_message'] = [
      '#type' => 'text_format',
      '#format' => 'basic_html',
      '#title' => $this->t('Prompt message'),
      '#default_value' => $this->config($this->getEditableConfigNames()[0])
        ->get('prompt_message') ?? $this->t('The server is taking too long to respond. Would you like to switch to eco-mode ?'),
      '#description' => $this->t('The text to display when the server response time exceeds the maximum allowed time.'),
    ];

    $form['details']['text_color'] = [
      '#type' => 'color',
      '#title' => $this->t('Message text color'),
      '#default_value' => $this->config($this->getEditableConfigNames()[0])
        ->get('text_color') ?? '#FFFFFF',
      '#description' => $this->t('The color of the text in the prompt message.'),
    ];

    $form['details']['background_color'] = [
      '#type' => 'color',
      '#title' => $this->t('Background color'),
      '#default_value' => $this->config($this->getEditableConfigNames()[0])
        ->get('background_color') ?? '#FF0000',
      '#description' => $this->t('The color of the background in the prompt message.'),
    ];

    $form['details']['enabled_admin_page'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable eco-mode on admin pages'),
      '#default_value' => $this->config($this->getEditableConfigNames()[0])
        ->get('enabled_admin_page') ?? 0,
      '#description' => $this->t('If checked, eco-mode will be enabled (Check for server response time) on admin pages.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable(self::CONFIG_NAME)
      ->set('latency', $form_state->getValue('latency'))
      ->set('interval', $form_state->getValue('interval'))
      ->set('prompt_message', $form_state->getValue('prompt_message')['value'])
      ->set('text_color', $form_state->getValue('text_color'))
      ->set('background_color', $form_state->getValue('background_color'))
      ->set('enabled_admin_page', $form_state->getValue('enabled_admin_page'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
