<?php

namespace Drupal\eco_mode;

use Drupal\Core\Field\FieldItemListInterface;

/**
 * Class FormatterHelper.
 *
 *  Helper class.
 *
 * @package Drupal\eco_mode
 */
class FormatterHelper {

  /**
   * Get the base settings.
   *
   * @return array
   *   The base settings.
   */
  public static function getBaseSettings(): array {
    return [
      'eco_mode' => FALSE,
      'text' => '',
      'ajax' => FALSE,
    ];
  }

  /**
   * Get the field lazy builder.
   *
   * @param array $elements
   *   The field element.
   * @param array $settings
   *   The settings.
   * @param \Drupal\Core\Field\FieldItemListInterface $items
   *   The items.
   * @param string $viewMode
   *   The view mode.
   *
   * @return array
   *   The lazy builder array.
   */
  public static function fieldLazyBuilder(array $elements, array $settings, FieldItemListInterface $items, string $viewMode): array {
    return [
      '#lazy_builder' => [
        'eco_mode.eco_mode_manager:renderEcoMode',
        [
          serialize($elements),
          serialize($settings),
          serialize($items),
          $viewMode,
        ],
      ],
      '#cache' => [
        'contexts' => [
          'cookies:eco_mode',
          'url.query_args:eco_ajax',
        ],
      ],
    ];
  }

}
