<?php

namespace Drupal\eco_mode\Manager;

use Symfony\Component\HttpFoundation\Cookie;

/**
 * Class EcoModeManager.
 *
 *  Eco mode manager.
 *
 * @package Drupal\eco_mode\Manager
 */
interface EcoModeManagerInterface {

  /**
   * Check if the cookie exists.
   *
   * @return bool
   *   The cookie exists.
   */
  public function cookieExists(): bool;

  /**
   * Get the new cookie object.
   *
   * @param int $value
   *   The cookie value.
   *
   * @return \Symfony\Component\HttpFoundation\Cookie
   *   The cookie object.
   */
  public function getNewCookieObject(int $value = 0): Cookie;

  /**
   * Get the cookie name.
   *
   * @return string
   *   The cookie name.
   */
  public function getCookieName(): string;

  /**
   * Get the cookie value.
   *
   * @return float|bool|int|string|null
   *   The cookie value.
   */
  public function getCookieValue(): float | bool | int | string | null;

  /**
   * Set the cookie value.
   *
   * @param float|bool|int|string|null $value
   *   The cookie value.
   *
   * @return float|bool|int|string|null
   *   The cookie value.
   */
  public function setCookieValue(float | bool | int | string | null $value): float | bool | int | string | null;

  /**
   * Set the cookie value.
   *
   * @return int
   *   The cookie value.
   */
  public function getSwitchEcoModeNewCookieValue(): int;

  /**
   * Get the cookie value.
   *
   * @return int
   *   The cookie value.
   */
  public function getEcoModeCookieValue(): int;

  /**
   * Get the request origin.
   *
   * @return string|null
   *   The request origin.
   */
  public function getRequestReferUrl(): ?string;

  /**
   * Get the CSRF token.
   *
   * @return string
   *   The CSRF token.
   */
  public function getCsrfToken(): string;

  /**
   * Validate the CSRF token.
   *
   * @param string $token
   *   The CSRF token.
   *
   * @return bool
   *   The CSRF token is valid.
   */
  public function validateCsrfToken(string $token): bool;

}
