<?php

declare(strict_types=1);

namespace Drupal\eco_mode\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\eco_mode\Manager\EcoModeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides an eco-mode switch block.
 *
 * @Block(
 *   id = "eco_mode_switch",
 *   admin_label = @Translation("Eco mode switch"),
 *   category = @Translation("Eco"),
 * )
 */
final class EcoModeSwitchBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Constructs the plugin instance.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    protected EcoModeManagerInterface $ecoModeManager,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
    return new self(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('eco_mode.eco_mode_manager'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    return [
      '#theme' => 'eco_mode_switch',
      '#token' => $this->ecoModeManager->getCsrfToken(),
    ];
  }

}
