<?php

namespace Drupal\eco_mode\Trait;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\eco_mode\Manager\EcoModeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Trait BaseFormatterTrait.
 *
 * The base formatter trait.
 *
 * @package Drupal\eco_mode\Trait
 */
trait BaseFormatterTrait {

  /**
   * Eco mode manager.
   *
   * @var \Drupal\eco_mode\Manager\EcoModeManagerInterface
   *   The eco mode manager.
   */
  protected EcoModeManagerInterface $ecoModeManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->ecoModeManager = $container->get('eco_mode.eco_mode_manager');
    return $instance;
  }

  /**
   * Get the base view elements.
   *
   * @param \Drupal\Core\Field\FieldItemListInterface $items
   *   The field items.
   * @param string $langcode
   *   The language.
   *
   * @return array
   *   The base view elements.
   */
  protected function getBaseViewElements(FieldItemListInterface $items, string $langcode): array {
    $elements = parent::viewElements($items, $langcode);
    if (empty($this->getSetting('eco_mode'))) {
      return $elements;
    }
    return $this->ecoModeManager->renderEcoMode($elements, $this->getSettings(), $items, $this->viewMode);
  }

  /**
   * Get the base setting form.
   *
   * @param array $form
   *   The form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   *
   * @return array
   *   The base setting form.
   */
  protected function getBaseSettingForm(array $form, FormStateInterface $form_state): array {
    $form['eco_mode'] = [
      '#type' => 'checkbox',
      '#title' => t('Enable eco mode'),
      '#default_value' => $this->getSetting('eco_mode'),
      '#description' => t('Enable field for eco mode.'),
    ];
    $form['text'] = [
      '#type' => 'textfield',
      '#title' => t('Text to display'),
      '#default_value' => $this->getSetting('text'),
      '#description' => t('Text to display instead of image.'),
      '#states' => [
        'visible' => [
          ':input[name="fields[field_media_image][settings_edit_form][settings][eco_mode]"]' => ['checked' => TRUE],
        ],
      ],
    ];
    $form['ajax'] = [
      '#type' => 'checkbox',
      '#title' => t('Generate link to load image'),
      '#default_value' => $this->getSetting('ajax'),
      '#description' => t('Display a link to load image.'),
      '#states' => [
        'visible' => [
          ':input[name="fields[field_media_image][settings_edit_form][settings][eco_mode]"]' => ['checked' => TRUE],
        ],
      ],
    ];
    return $form;
  }

}
